@@ -615,7 +615,7 @@ class ChimeSDKMessagingClient(BaseClient):
         NextToken: str = ...
     ) -> SearchChannelsResponseTypeDef:
         """
-        Allows an `AppInstanceUser` to search the channels that they belong to.
+        Allows `ChimeBearer` to search channels by channel members.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.search_channels)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#search_channels)
